### Identifying priority areas to manage mobile bottom fishing on seabed carbon in the UK

##See Table S1 for information on additional input data sources required to download

#### LOAD PACKAGES
rm(list=ls())
library(spatialEco)
library(rgdal)
library(sf)
library(fasterize)
library(raster)
library(ggplot2)
library(terra)
setwd(dirname(rstudioapi::getActiveDocumentContext()$path))


##### READ IN DATA
UKEEZ <- st_read("./Areas/UKEEZ_Outline_Eq.shp")
UKEEZLand <- st_read("./Areas/UKEEZ w land_Eq.shp")
UK12nm <- st_read("./Areas/12nm.shp")
UK12nmEq <- st_read("./Areas/12nm_Eq.shp")
ScotMA <- st_read("./Areas/ScotlandMA.shp")


##Smeaton et al. 20201
OCShelfSmeat <- raster("./UK EEZ - Sedimentary Carbon/OC_Density/UK Outer Shelf.tif")
DBD <- raster("./UK EEZ - Sedimentary Carbon/Dry_Bulk_Density/Outer Shelf.tif")
#Crop Smeaton excess space
OCShelfSmeat <- crop(OCShelfSmeat, extent(-15,3.6,47,64))
DBDUK <-crop (DBD,extent(-15,3.6,47,64))

##Diesing et al 2021 
Diesing21OC <- raster("./Diesing_2021/OCdensity GeomFix.tif")

##Wilson et al. 2018
WilsonOC <- raster("./Wilson 2018/kg C m^-2.tif")

##Diesing et al. 2017
Dies17Perc <- raster("./Diesing-etal_2017/SedimentPOC_percent.tif")


## ICES Fishing Data
#2021 Publication
fish <- st_read("./EU_data_products_EUTRADE/Data product/VMS aggregated fishing data/ICESTrade_shapefiles/ICESTrade_shapefiles.shp")
#2018 Publication
Beam9 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2009/OSPAR_intensity_Beam_2009.shp")
Beam10 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2010/OSPAR_intensity_Beam_2010.shp")
Beam11 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2011/OSPAR_intensity_Beam_2011.shp")
Beam12 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2012/OSPAR_intensity_Beam_2012.shp")
Beam13 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2013/OSPAR_intensity_Beam_2013.shp")
Beam14 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2014/OSPAR_intensity_Beam_2014.shp")
Beam15 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2015/OSPAR_intensity_Beam_2015.shp")
Beam16 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2016/OSPAR_intensity_Beam_2016.shp")
Beam17 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2017/OSPAR_intensity_Beam_2017.shp")
Dredge9 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2009/OSPAR_intensity_Dredge_2009.shp")
Dredge10 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2010/OSPAR_intensity_Dredge_2010.shp")
Dredge11 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2011/OSPAR_intensity_Dredge_2011.shp")
Dredge12 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2012/OSPAR_intensity_Dredge_2012.shp")
Dredge13 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2013/OSPAR_intensity_Dredge_2013.shp")
Dredge14 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2014/OSPAR_intensity_Dredge_2014.shp")
Dredge15 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2015/OSPAR_intensity_Dredge_2015.shp")
Dredge16 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2016/OSPAR_intensity_Dredge_2016.shp")
Dredge17 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2017/OSPAR_intensity_Dredge_2017.shp")
Otter9 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2009/OSPAR_intensity_Otter_2009.shp")
Otter10 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2010/OSPAR_intensity_Otter_2010.shp")
Otter11 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2011/OSPAR_intensity_Otter_2011.shp")
Otter12 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2012/OSPAR_intensity_Otter_2012.shp")
Otter13 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2013/OSPAR_intensity_Otter_2013.shp")
Otter14 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2014/OSPAR_intensity_Otter_2014.shp")
Otter15 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2015/OSPAR_intensity_Otter_2015.shp")
Otter16 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2016/OSPAR_intensity_Otter_2016.shp")
Otter17 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2017/OSPAR_intensity_Otter_2017.shp")
Seine9 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2009/OSPAR_intensity_Seine_2009.shp")
Seine10 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2010/OSPAR_intensity_Seine_2010.shp")
Seine11 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2011/OSPAR_intensity_Seine_2011.shp")
Seine12 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2012/OSPAR_intensity_Seine_2012.shp")
Seine13 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2013/OSPAR_intensity_Seine_2013.shp")
Seine14 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2014/OSPAR_intensity_Seine_2014.shp")
Seine15 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2015/OSPAR_intensity_Seine_2015.shp")
Seine16 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2016/OSPAR_intensity_Seine_2016.shp")
Seine17 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2017/OSPAR_intensity_Seine_2017.shp")
Fish9 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2009/OSPAR_intensity_total_2009.shp")
Fish10 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2010/OSPAR_intensity_total_2010.shp")
Fish11 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2011/OSPAR_intensity_total_2011.shp")
Fish12 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2012/OSPAR_intensity_total_2012.shp")
Fish13 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2013/OSPAR_intensity_total_2013.shp")
Fish14 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2014/OSPAR_intensity_total_2014.shp")
Fish15 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2015/OSPAR_intensity_total_2015.shp")
Fish16 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2016/OSPAR_intensity_total_2016.shp")
Fish17 = st_read("./ICES.2018.OSPAR-spatial-data-fishing-intensity/2017/OSPAR_intensity_total_2017.shp")


#ScotMap
ScotNEP <- raster("./trawls_nephrops/ScotMap_Central_Trawls_NEP_numberVessel_aggr_3_230713/ScotMap_Central_Trawls_NEP_numberVessel_aggr_3_230713.tif")
ScotOther <- raster("./Trawls_non-nephrops/ScotMap_Central_Trawls_notNEP_numberVessel_aggr_3_230713/ScotMap_Central_Trawls_notNEP_numberVessel_aggr_3_230713.tif")
ScotDredge <- raster("./towed-dredges_SCE/ScotMap_Central_TowedDredges_SCE_numberVessel_aggr_3_230713/ScotMap_Central_TowedDredges_SCE_numberVessel_aggr_3_230713.tif")
ScotNEPValue <- raster("./trawls_nephrops/ScotMap_Central_Trawls_NEP_monetaryValue_220713/ScotMap_Central_Trawls_NEP_monetaryValue_220713.tif")
ScotOtherValue <- raster("./Trawls_non-nephrops/ScotMap_Central_Trawls_notNEP_monetaryValue_220713/ScotMap_Central_Trawls_notNEP_monetaryValue_220713.tif")
ScotDredgeValue <- raster("./towed-dredges_SCE/ScotMap_Central_TowedDredges_SCE_monetaryValue_220713/ScotMap_Central_TowedDredges_SCE_monetaryValue_220713.tif")

#CEFAS Inshore data
CEFASDat = st_read("./Recordset_8763/Recordset_8763Polygon.shp")
CEFASDat2 = st_read("./Sightings based-Inshore/2007-2009/RFE_Inshore_Sightings.shp")
##### END OF DATA READ IN





#####CREATING OC STOCK LAYER
r=raster(as(UKEEZ, "Spatial"),res=500)

#Smeaton 2021 - WGS1984 - 0.01 deg resolution - kg m-2 - 10 cm depth
SmeatSmall = disaggregate(OCShelfSmeat,2) 
SmeatReproj = projectRaster(SmeatSmall,r)
plot(SmeatReproj)

#Diesing 2021 - (kg/m3) - assumes equal area of grid cell - A = 250,000 m2 or 0.25km2 - accurate to 10cm depth
Dies21km2 = Diesing21OC/10 #to get top 10 cm
DiesReproj = projectRaster(Dies21km2,r)
plot(DiesReproj)

#Wilson 2018 - kg/m2 - WGS 1984 0.125 deg x 0.125 deg - 10cm depth
WilsonSmall=disaggregate(WilsonOC,(0.125/0.005))
WilsonReproj = projectRaster(WilsonSmall,r)
plot(WilsonReproj)

#Diesing 2017- % - assumes equal area of grid cell - A = 250,000 m2 or 0.25km2 - states pixel stock = % * DBD * 0.1 * 250,000 m2
DBDSmall = disaggregate(DBDUK,2)
Dies17Allign = projectRaster(Dies17Perc,DBDSmall)
Dies17km2 = (Dies17Allign/100)*DBDSmall*0.1
Dies17Reproj = projectRaster(Dies17km2,r)
plot(Dies17Reproj)

#Combine
Stack = stack(SmeatReproj,DiesReproj,WilsonReproj,Dies17Reproj)
OCShelfAll <- calc(Stack, fun = mean, na.rm = T)
plot(OCShelfAll)
OCShelf <- mask(OCShelfAll,UKEEZLand)
plot(OCShelf)

OCConc = OCShelf*1000 #t per km2
plot(OCConc)
cellStats(OCConc,mean)
#425.0985
cellStats(OCConc,sd)
#147.7503
#writeRaster(OCConc,"OCConc.tif",overwrite=TRUE)

#Change to stock
StockTot = OCShelf*250 #Stock in tonnes within a 0.25km2 pixel
#writeRaster(StockTot,"StockTot.tif",overwrite=TRUE)
cellStats(StockTot, sum)
#307228581

#Modeled Area
AreaTot=OCShelf
AreaTot[OCShelf>=0]<-0.25
cellStats(AreaTot,sum)
#722723.2 km2







#################FISHING DISTURBANCE #########################
###ICES 2018
Beam = rbind(Beam9,Beam10,Beam11,Beam12,Beam13,Beam14,Beam15,Beam16,Beam17)
Dredge = rbind(Dredge9,Dredge10,Dredge11,Dredge12,Dredge13,Dredge14,Dredge15,Dredge16,Dredge17)
Otter = rbind(Otter9,Otter10,Otter11,Otter12,Otter13,Otter14,Otter15,Otter16,Otter17)
Seine = rbind(Seine9,Seine10,Seine11,Seine12,Seine13,Seine14,Seine15,Seine16,Seine17)

Beam2=subset(Beam,SurfSAR!=-9)
Dredge2=subset(Dredge,SurfSAR!=-9)
Otter2=subset(Otter,SurfSAR!=-9)
Seine2=subset(Seine,SurfSAR!=-9)

r <- raster(as(Beam2, "Spatial"),res=0.05)
BeamRastSAR = fasterize(Beam2,r,field="SurfSAR",fun="sum")/9 #AVERAGE OVER 9 YEARS
BeamSAR18 = extend(BeamRastSAR,extent(-15,13,48.05,62),value=NA)
plot(BeamSAR18)

r <- raster(as(Dredge2, "Spatial"),res=0.05)
DredgeRastSAR = fasterize(Dredge2,r,field="SurfSAR",fun="sum")/9 #AVERAGE OVER 9 YEARS
DredgeSAR18 = extend(DredgeRastSAR,extent(BeamRastSAR),value=NA)
plot(DredgeSAR18)

r <- raster(as(Otter2, "Spatial"),res=0.05)
OtterRastSAR = fasterize(Otter2,r,field="SurfSAR",fun="sum")/9 #AVERAGE OVER 9 YEARS
OtterSAR18 = extend(OtterRastSAR,extent(BeamRastSAR),value=NA)
plot(OtterSAR18)

r <- raster(as(Seine2, "Spatial"),res=0.05)
SeineRastSAR = fasterize(Seine2,r,field="SurfSAR",fun="sum")/9 #AVERAGE OVER 9 YEARS
SeineSAR18 = extend(SeineRastSAR,extent(BeamRastSAR),value=NA)
plot(SeineSAR18)





###ICES 2021 Publication to raster
fish$MBCG_SAR = as.factor(as.character(fish$MBCG_SAR))
fishCAT<-unique(fish$MBCG_SAR)
Effort <- as.data.frame(matrix(nrow = length(fishCAT), ncol = 2))
colnames(Effort) <- c("Name","SAR")
Effort$Name = fishCAT
Effort$SAR = c(0.05,0.3,0.75,3,7.5,10,0) #Median values from SAR range
Effort

fish$newDRBMOL_SAR <- Effort$SAR[match(fish$DRBMOL_SAR,Effort$Name)]
fish$newOTCRU_SAR <- Effort$SAR[match(fish$OTCRU_SAR,Effort$Name)]
fish$newOTDMF_SAR <- Effort$SAR[match(fish$OTDMF_SAR,Effort$Name)]
fish$newOTMIX_SAR <- Effort$SAR[match(fish$OTMIX_SAR,Effort$Name)]
fish$newOTSPF_SAR <- Effort$SAR[match(fish$OTSPF_SAR,Effort$Name)]
fish$newSDNDMF_SAR <- Effort$SAR[match(fish$SDNDMF_SAR,Effort$Name)]
fish$newSSCDMF_SAR <- Effort$SAR[match(fish$SSCDMF_SAR,Effort$Name)]
fish$newTBBCRU_SAR <- Effort$SAR[match(fish$TBBCRU_SAR,Effort$Name)]
fish$newTBBDMF_SAR <- Effort$SAR[match(fish$TBBDMF_SAR,Effort$Name)]
fish$newTBBMOL_SAR <- Effort$SAR[match(fish$TBBMOL_SAR,Effort$Name)]


fish$Dredge = fish$newDRBMOL_SAR
fish$Otter = fish$newOTCRU_SAR + fish$newOTDMF_SAR + fish$newOTMIX_SAR + fish$newOTSPF_SAR
fish$Seine = fish$newSDNDMF_SAR + fish$newSSCDMF_SAR
fish$Beam = fish$newTBBCRU_SAR + fish$newTBBDMF_SAR + fish$newTBBMOL_SAR



r <- raster(as(fish, "Spatial"),res=0.05)

DredgeSAR21 = fasterize(fish,r,field="Dredge")
DredgeSAR21[is.na(DredgeSAR21)]<-0
plot(DredgeSAR21)
OtterSAR21 = fasterize(fish,r,field="Otter")
OtterSAR21[is.na(OtterSAR21)]<-0
plot(OtterSAR21)
SeineSAR21 = fasterize(fish,r,field="Seine")
SeineSAR21[is.na(SeineSAR21)]<-0
plot(SeineSAR21)
BeamSAR21 = fasterize(fish,r,field="Beam")
BeamSAR21[is.na(BeamSAR21)]<-0
plot(BeamSAR21)


### FILL ICES 2018 WITH ICES 2021
DredgeSAR18Ext = crop(DredgeSAR18,extent(DredgeSAR21))
DredgeSAR18Ext = extend(DredgeSAR18Ext,extent(DredgeSAR21))
ICESDredgeRastSAR = cover(DredgeSAR18Ext,DredgeSAR21)
plot(ICESDredgeRastSAR)

OtterSAR18Ext = crop(OtterSAR18,extent(OtterSAR21))
OtterSAR18Ext = extend(OtterSAR18Ext,extent(OtterSAR21))
ICESOtterRastSAR = cover(OtterSAR18Ext,OtterSAR21)
plot(ICESOtterRastSAR)

SeineSAR18Ext = crop(SeineSAR18,extent(SeineSAR21))
SeineSAR18Ext = extend(SeineSAR18Ext,extent(SeineSAR21))
ICESSeineRastSAR = cover(SeineSAR18Ext,SeineSAR21)
plot(ICESSeineRastSAR)

BeamSAR18Ext = crop(BeamSAR18,extent(BeamSAR21))
BeamSAR18Ext = extend(BeamSAR18Ext,extent(BeamSAR21))
ICESBeamRastSAR = cover(BeamSAR18Ext,BeamSAR21)
plot(ICESBeamRastSAR)




###ScotMap to raster
ScotNEP[is.na(ScotNEP[])] <- 0 #NAs to zero
ScotNEP[ScotNEP==3] <- 1 #3 is actually 1-3 so change to conservative 1 vessel
plot(ScotNEP)
ScotOther[is.na(ScotOther[])] <- 0
ScotOther[ScotOther==3] <- 1
plot(ScotOther)
ScotDredge[is.na(ScotDredge[])] <- 0
ScotDredge[ScotDredge==3] <- 1
plot(ScotDredge)

#Convert each to footprint based off Eigard 2016 hourlt swept 
#Traveling 3 knots or 5.5km per hour (also based on Eigard) 
TotNuScotMap = ScotNEP+ScotOther+ScotDredge
plot(TotNuScotMap)
AreaScot = area(TotNuScotMap,na.rm=T)
plot(AreaScot)
cellStats(AreaScot,mean)
#mean pixel size is ~4km2 (or 2km by 2km)
#so would travel through aprox 2.75 pixels per hour
NepFoot = ScotNEP*(1.2/2.75)
OtherFoot = ScotOther*(0.5/2.75)
DredgeFoot = ScotDredge*(0.1/2.75)
#Divide by area of pixel to create SAR
ScotNepSAR = (NepFoot/AreaScot)
ScotNepSAR= mask(ScotNepSAR,ScotMA)
plot(ScotNepSAR)
ScotOtherSAR = (OtherFoot/AreaScot)
ScotOtherSAR= mask(ScotOtherSAR,ScotMA)
plot(ScotOtherSAR)
ScotDredgeSAR = (DredgeFoot/AreaScot)
ScotDredgeSAR= mask(ScotDredgeSAR,ScotMA)
plot(ScotDredgeSAR)






##CEFAS to raster
r <- raster(as(CEFASDat, "Spatial"),res=0.025)
CEFASTrawl1 = fasterize(CEFASDat,r,field="TRAWLING",fun="min")
CEFASTrawl1[is.na(CEFASTrawl1)] <-0 
r <- raster(as(CEFASDat2, "Spatial"),res=0.025)
CEFASTrawl2 = fasterize(CEFASDat2,r,field="SUM_TR_N",fun="min")
CEFASTrawl2[is.na(CEFASTrawl2)] <-0 
CEFASTrawlAll=(CEFASTrawl1+CEFASTrawl2)/2
CEFASTrawl=mask(CEFASTrawlAll,UK12nm)
plot(CEFASTrawl)

r <- raster(as(CEFASDat, "Spatial"),res=0.025)
CEFASDredge1 = fasterize(CEFASDat,r,field="DREDGING",fun="min")
CEFASDredge1[is.na(CEFASDredge1)] <-0 
r <- raster(as(CEFASDat2, "Spatial"),res=0.025)
CEFASDredge2 = fasterize(CEFASDat2,r,field="SUM_DR_N",fun="min")
CEFASDredge2[is.na(CEFASDredge2)] <-0 
CEFASDredgeAll=(CEFASDredge1+CEFASDredge2)/2
CEFASDredge=mask(CEFASDredgeAll,UK12nm)
plot(CEFASDredge)

CEFASTrawlScale = (CEFASTrawl/cellStats(CEFASTrawl,max))
TrawlScot = ScotNepSAR + ScotOtherSAR
CEFASTrawl2 = CEFASTrawlScale*cellStats(TrawlScot,max)*2.1266
plot(CEFASTrawl2)

CEFASDredgeScale = (CEFASDredge/cellStats(CEFASDredge,max))
CEFASDredge2 = CEFASDredgeScale*cellStats(ScotDredgeSAR,max)*2.1266
plot(CEFASDredge2)






#####ALLIGN RASTERS
FinalICESDredgeSAR = disaggregate(ICESDredgeRastSAR,2)
FinalICESSeineSAR = disaggregate(ICESSeineRastSAR,2)
FinalICESBeamSAR = disaggregate(ICESBeamRastSAR,2)
FinalICESOtterSAR = disaggregate(ICESOtterRastSAR,2)

FinalScotDredgeSAR  = crop(ScotDredgeSAR,extent(FinalICESDredgeSAR))
FinalScotDredgeSAR = extend(FinalScotDredgeSAR,extent(FinalICESDredgeSAR))
FinalScotDredgeSAR[is.na(FinalScotDredgeSAR)]<-0

FinalScotNEPSAR  = crop(ScotNepSAR,extent(FinalICESDredgeSAR))
FinalScotNEPSAR = extend(FinalScotNEPSAR,extent(FinalICESDredgeSAR))
FinalScotNEPSAR[is.na(FinalScotNEPSAR)]<-0

FinalScotOtherSAR  = crop(ScotOtherSAR,extent(FinalICESDredgeSAR))
FinalScotOtherSAR = extend(FinalScotOtherSAR,extent(FinalICESDredgeSAR))
FinalScotOtherSAR[is.na(FinalScotOtherSAR)]<-0

FinalCEFASDredgeSAR  = crop(CEFASDredge2,extent(FinalICESDredgeSAR))
FinalCEFASDredgeSAR = extend(FinalCEFASDredgeSAR,extent(FinalICESDredgeSAR))
FinalCEFASDredgeSAR[is.na(FinalCEFASDredgeSAR)]<-0

FinalCEFASTrawlSAR  = crop(CEFASTrawl2,extent(FinalICESDredgeSAR))
FinalCEFASTrawlSAR = extend(FinalCEFASTrawlSAR,extent(FinalICESDredgeSAR))
FinalCEFASTrawlSAR[is.na(FinalCEFASTrawlSAR)]<-0


SARStack = stack(FinalICESDredgeSAR, FinalICESOtterSAR, FinalICESSeineSAR, FinalICESBeamSAR, FinalScotDredgeSAR, FinalScotNEPSAR, FinalScotOtherSAR, FinalCEFASDredgeSAR, FinalCEFASTrawlSAR)
#writeRaster(SARStack,"SARFinalStack")


#######CONVERT SAR TO SVR (Proportion of 10cm)
ICESDredgeSVR = FinalICESDredgeSAR*(5.47/10)
ICESOtterSVR = FinalICESOtterSAR*(2.44/10)
ICESSeineSVR = FinalICESSeineSAR*(0.5/10)
ICESBeamSVR = FinalICESBeamSAR*(2.72/10)
ScotDredgeSVR = FinalScotDredgeSAR*(5.47/10)
ScotNEPSVR = FinalScotNEPSAR*(2.44/10)
ScotOtherSVR = FinalScotOtherSAR*(2.44/10)
CEFASDredgeSVR = FinalCEFASDredgeSAR*(5.47/10)
CEFASTrawlSVR = FinalCEFASTrawlSAR*(2.44/10)




#######FINAL SVR
SVRStack = stack(ICESDredgeSVR, ICESOtterSVR, ICESSeineSVR, ICESBeamSVR, ScotDredgeSVR, ScotNEPSVR, ScotOtherSVR, CEFASDredgeSVR, CEFASTrawlSVR)
SmallSVR=disaggregate(SVRStack,5)
AlSVR = terra::project(rast(SmallSVR),rast(OCShelf))
AlSVRback = stack(AlSVR)
SVRFinalStack = mask(AlSVRback,OCShelf)
#writeRaster(SVRFinalStack,"SVRFinalStack")
SVR = calc(SVRFinalStack,sum)
plot(SVR)
#writeRaster(SVR,"SVR.tif",overwrite=TRUE)

cellStats(SVR,mean)
#0.3048764
cellStats(SVR,sd)
#0.5338403
cellStats(SVR,max)
#8.502287


Unfished=SVR
Unfished[SVR>0]<-NA
UnfishedArea = mask(AreaTot,Unfished)
plot(UnfishedArea)
cellStats(UnfishedArea,sum)/cellStats(AreaTot,sum)
#0.2620751







############### CARBON DISTURBACE ##################
OCDisturb = StockTot*SVR
plot(OCDisturb)
#writeRaster(OCDisturb,"OCDisturb.tif",overwrite=TRUE)
OCDisturbConc = OCDisturb*4
#writeRaster(OCDisturbConc,"OCDisturbConc.tif",overwrite=TRUE)

cellStats(OCDisturb,sum)
#108969402
cellStats(OCDisturbConc,mean)
cellStats(OCDisturbConc,sd)
# 150.7761 +/- 332.1444









########## LANDINGS VALUE DATA #########################

###ICES 2018 Publication to raster
r <- raster(as(Fish9, "Spatial"),res=0.05)
vRast9 = fasterize(Fish9,r,field="totvalue",fun="min")
vRast9[vRast9==-9] <- NA
vRast10 = fasterize(Fish10,r,field="totvalue",fun="min")
vRast10[vRast10==-9] <- NA
vRast11 = fasterize(Fish11,r,field="totvalue",fun="min")
vRast11[vRast11==-9] <- NA
vRast12= fasterize(Fish12,r,field="totvalue",fun="min")
vRast12[vRast12==-9] <- NA
vRast13 = fasterize(Fish13,r,field="totvalue",fun="min")
vRast13[vRast13==-9] <- NA
vRast14 = fasterize(Fish14,r,field="totvalue",fun="min")
vRast14[vRast14==-9] <- NA
vRast15 = fasterize(Fish15,r,field="totvalue",fun="min")
vRast15[vRast15==-9] <- NA
vRast16 = fasterize(Fish16,r,field="totvalue",fun="min")
vRast16[vRast16==-9] <- NA
vRast17 = fasterize(Fish17,r,field="totvalue",fun="min")
vRast17[vRast17==-9] <- NA

FishStack = stack(vRast9,vRast10,vRast11,vRast12,vRast13,vRast14,vRast15,vRast16,vRast17)
Mainfish = calc(FishStack, fun = mean, na.rm = T)
Value1 = extend(Mainfish,extent(-15,3.6,47,64),value=NA)
plot(Value1)


###ICES 2021 Publication to raster
fish$MBCG_EUR = as.factor(as.character(fish$MBCG_EUR))
fishEUR<-unique(fish$MBCG_EUR)

value2 <- as.data.frame(matrix(nrow = length(fishEUR), ncol = 2))
colnames(value2) <- c("Name","value")
value2
value2$Name = fishEUR
value2
value2$value = c(50,550,5500,55000,100000,NA) #Median values from value range
value2

fish$value = value2$value[match(fish$MBCG_EUR,value2$Name)]
unique(fish$value)

r <- raster(as(fish, "Spatial"),res=0.05)

fishRast = fasterize(fish,r,field="value",fun="min")
plot(fishRast)
Value2=fishRast
Value2[is.na(Value2[])] <- 0
Value2 = crop(Value2,extent(Value1))
plot(Value2)


##Combining Values
CombiValue = cover(Value1,Value2)
AreaValue=area(CombiValue)
CombiValueConc = CombiValue/AreaValue
AlCombiValueConc <- terra::project(rast(CombiValueConc),rast(OCShelf))
AlCombiValueConc=raster(AlCombiValueConc)
AlCombiValueConc=mask(AlCombiValueConc,OCShelf)
AlCombiValue=AlCombiValueConc*AreaTot
ValueCombi = AlCombiValue*0.835
ValueCombi[SVR==0]<-0
plot(ValueCombi)
cellStats(ValueCombi,mean)
#163.2077
cellStats(ValueCombi,sd)
#302.4244
cellStats(ValueCombi,sum)
#471816005



###SCOTMAP VALUE
ScotValue = ScotNEPValue+ScotDredgeValue+ScotOtherValue
ScotValueMap= mask(ScotValue,ScotMA)
ScotValueArea=area(ScotValueMap)
ScotValueConc=ScotValueMap/ScotValueArea
AlScotValueConc = terra::project(rast(ScotValueConc),rast(OCShelf))
AlScotValueConc=raster(AlScotValueConc)
AlScotValueConc=mask(AlScotValueConc,OCShelf)
ValueScot=AlScotValueConc*AreaTot
plot(ValueScot)
cellStats(ValueScot,mean)
#14.8661
cellStats(ValueScot,sd)
#52.59041
cellStats(ValueScot,sum)
#11152293



#CEFAS VALUE
CombiCEFASAR = CEFASTrawl2 + CEFASDredge2
SmallCombiCEFASAR=disaggregate(CombiCEFASAR,5)
AlSmallCombiCEFASAR = terra::project(rast(SmallCombiCEFASAR),rast(OCShelf))
AlSmallCombiCEFASAR = raster(AlSmallCombiCEFASAR)
AlSmallCombiCEFASAR = mask(AlSmallCombiCEFASAR,OCShelf)
EstEngWalTot = 10972388
CefasNo0 = AlSmallCombiCEFASAR
CefasNo0[AlSmallCombiCEFASAR==0]<-NA
Cefasprop = CefasNo0/cellStats(CefasNo0,sum)
ValueCEFAS=Cefasprop*EstEngWalTot
plot(ValueCEFAS)
cellStats(ValueCEFAS,sum)
#10972388
cellStats(ValueCEFAS,mean)
#93.79392
cellStats(ValueCEFAS,sd)
#128.9122


#Combine all three
StackValue = stack(ValueCombi,ValueScot,ValueCEFAS)
Value = calc(StackValue,sum,na.rm=T)
Value = mask(Value,OCShelf)
plot(Value)
#writeRaster(Value,"Value.tif",overwrite=TRUE)
cellStats(Value,sum)
#493940687


StackValueConc = StackValue*4
StackValueConc[is.na(StackValueConc)]<-0
#writeRaster(StackValueConc,"StackValueConc")


#ValueConc 
ValueConc = Value*4
#writeRaster(ValueConc,"ValueConc.tif",overwrite=TRUE)
cellStats(ValueConc,mean)
cellStats(ValueConc,sd)
#683.4437 +/- 1227.756


#Fished areas value Conc
ValueNo0 = ValueConc
ValueNo0[ValueConc==0]<-NA
cellStats(ValueNo0,mean)
cellStats(ValueNo0,sd)
#933.7116 +/ 1351.181













####CLEAN AND START AGAIN
rm(list=ls())
StockTot = raster("./StockTot.tif")
OCConc = raster("./OCConc.tif")
OCDisturb = raster("./OCDisturb.tif")
SVR = raster("./SVR.tif")
SVRFinalStack = brick("./SVRFinalStack.grd")
AreaTot=StockTot
AreaTot[StockTot>=0]<-0.25
Value = raster("./Value.tif")

  

  

###################  PRIORITY AREAS #########################

#######SELECTING POTENTIAL PAs
#Function to select areas based on given percentage threshold of highest loss & stock values
AreaSelect <- function(threshold) {
  HighStockFish=StockTot
  HighStockFish[StockTot<quantile(StockTot,probs = 1-(threshold/100))]<-NA
  HighStockFish[SVR==0]<-NA
  HighStockFish[HighStockFish>0]<-1
  
  HighImpact=OCDisturb
  HighImpact[OCDisturb<quantile(OCDisturb,probs = 1-(threshold/100))]<-NA
  HighImpact[HighImpact>0]<-1
  
  TotMPA = sum(HighStockFish,HighImpact,na.rm=T)
  TotMPA[TotMPA==0]<-NA
  TotMPA[TotMPA>0]<-1
  
  CoarseMPA=aggregate(TotMPA,4,fun=max)
  
  ClumpMPA=clump(CoarseMPA,directions=8,gaps=FALSE)
  MPAPoly = rasterToPolygons(ClumpMPA, dissolve=TRUE)
  MPABuf = buffer(MPAPoly,width=2000,dissolve=TRUE)
  MPAs=remove.holes(MPABuf)
  MPAs=remove.holes(MPAs)
  
  AllMPAs = st_cast(st_as_sf(MPAs),"POLYGON")
  AllMPAs$ID = seq(from=1, to=length(AllMPAs$ID),by=1)
  
  MPAStats <- data.frame(matrix(ncol=8,nrow=length(AllMPAs$ID), dimnames=list(NULL, c("MPA", "Stock","PropStock","Impact","PropImpact","Effects","Value","PropValue"))))
  
  for (i in seq(from=1, to=length(AllMPAs$ID),by=1))  {
    MPAStock <- mask(StockTot,AllMPAs[i,])
    MPAImp <- mask(OCDisturb, AllMPAs[i,])
    MPAArea <- mask(AreaTot, AllMPAs[i,])
    MPAValue <- mask(Value, AllMPAs[i,])
    
    MPAStats$MPA[i] <- paste0(i)
    MPAStats$Stock[i] <- cellStats(MPAStock,sum)
    MPAStats$PropStock[i] <- cellStats(MPAStock,sum)/cellStats(StockTot,sum)*100
    MPAStats$Impact[i] <- cellStats(MPAImp,sum)
    MPAStats$PropImpact[i] <- cellStats(MPAImp,sum)/cellStats(OCDisturb,sum)*100
    MPAStats$Area[i]<- cellStats(MPAArea,sum)
    MPAStats$PropArea[i]<- cellStats(MPAArea,sum)/cellStats(AreaTot,sum)*100
    MPAStats$DensityImp [i] <- cellStats(MPAImp,sum)/cellStats(MPAArea,sum)
    MPAStats$DensityStock[i] <- cellStats(MPAStock,sum)/cellStats(MPAArea,sum)
    MPAStats$Value[i] <- cellStats(MPAValue,sum)
    MPAStats$PropValue[i] <- cellStats(MPAValue,sum)/cellStats(Value,sum)*100
  }
  
  
  #reduce noise
  LowMPA=subset(MPAStats, PropStock < 0.1 & PropImpact < 0.1) 
  LowMPA$RemMPA = as.numeric(LowMPA$MPA)*-1
  Remove=c(LowMPA$RemMPA)
  PotMPAs = AllMPAs[Remove,]
  PotMPAStats=subset(MPAStats, PropStock >= 0.1 | PropImpact >= 0.1)
  newlist <- list(PotMPAs,PotMPAStats)
  return(newlist)}


#Three sets of areas based on different thresholds
OnePerc <- AreaSelect(1)
OnePercPA = OnePerc[[1]]
OnePercPAStats = OnePerc[[2]]
plot(OnePercPA)

FivePerc <- AreaSelect(5)
FivePercPA = FivePerc[[1]]
FivePercPAStats = FivePerc[[2]]
plot(FivePercPA)

TenPerc <- AreaSelect(10)
TenPercPA = TenPerc[[1]]
TenPercPAStats = TenPerc[[2]]
plot(TenPercPA)




######FISHING DISPLACEMENT

FishDisp <- function(PASet,PASetStats){

ClosedAreas = mask(AreaTot,PASet)
ClosedAreas[ClosedAreas>0]<-1
ClosedAreas[ClosedAreas==0]<-NA
OpenAreas=AreaTot
OpenAreas[AreaTot>=0]<-1
OpenAreas[ClosedAreas>=0]<-NA

#Unfished Areas to NA
SVRDispStack = SVRFinalStack
SVRDispStack[SVRFinalStack==0]<-NA

#Blank SVR Layer
ReDifSum=SVR
ReDifSum[SVR>=0]<-0

for (i in 1:length(PASet$ID))  {  

PAArea = mask(AreaTot,PASet[i,])  
PASVR = mask(SVRFinalStack,PAArea) 
DispTot = cellStats(PASVR,sum)


#Make 200km buffers for ICES and 100km buffers for SCOTMap/CEFAS
Buffer200 = buffer(as_Spatial(PASet[i,]), width = 200*1000) 
Buff200 <- mask(AreaTot,Buffer200)
Clump200 = clump(Buff200)
Clump200[Clump200!=cellStats(Clump200,median)]<-NA
OnlyOpen200 = mask(Clump200,OpenAreas)
OnlyOpen200[PAArea>0]<-NA

Buffer100 = buffer(as_Spatial(PASet[i,]), width = 100*1000) 
Buff100 <- mask(AreaTot,Buffer100)
Clump100 = clump(Buff100)
Clump100[Clump100!=cellStats(Clump100,median)]<-NA
OnlyOpen100 = mask(Clump100,OpenAreas)
OnlyOpen100[PAArea>0]<-NA
BuffStack=stack(OnlyOpen200,OnlyOpen200,OnlyOpen200,OnlyOpen200,OnlyOpen100,OnlyOpen100,OnlyOpen100,OnlyOpen100,OnlyOpen100)
SVROutside=mask(SVRDispStack,BuffStack)


#Proportional displacement
OutsideTot = cellStats(SVROutside,sum)
OutsideProp=SVROutside/OutsideTot
PropReDist = OutsideProp*DispTot


#Distance from PA
DistArea=crop(PAArea,extent(Buffer200))
Agg=aggregate(DistArea,4)
Distance=distance(Agg,doEdge=TRUE)
Distsplit=disaggregate(Distance,4)
DistBack=extend(Distsplit,extent(PAArea),value=NA)
DistBack=crop(DistBack,extent(PAArea),value=NA)
DistBack[DistBack==0]<-2000


#Exponential displacement
Dist=mask(DistBack,SVROutside)
ExpStack=(0.75/(Dist^0.75))               
PropExpStack = ExpStack/cellStats(ExpStack,sum)
ExpRedis=PropExpStack*DispTot


#Take average
MeanRedis=(PropReDist+ExpRedis)/2


##All SVR and effect
AllRedis = calc(MeanRedis,sum,na.rm=T)
SVROutsideSum = calc(SVROutside,sum,na.rm=T)
NewSVR = AllRedis+SVROutsideSum

PASVRSum = mask(SVR,PAArea)
PASVRSum[is.na(PASVRSum)]<-0
OldSVR = PASVRSum+SVROutsideSum

NewDisturb = StockTot*NewSVR
OldDisturb = StockTot*OldSVR
Effect = cellStats(OldDisturb,sum)-cellStats(NewDisturb,sum)
PASetStats$Effects[i] = Effect                        

##Add Redis on to blank SVR
ReDifSum = ReDifSum+AllRedis}


#Final displaced SVR
SVROpen = SVR
SVROpen[ClosedAreas==1]<-0
FinalDispSVR = SVROpen+ReDifSum


newlist <- list(FinalDispSVR,PASetStats)  
return(newlist)}



DispOnePerc = FishDisp(OnePercPA,OnePercPAStats)
DispFivePerc = FishDisp(FivePercPA,FivePercPAStats)
DispTenPerc = FishDisp(TenPercPA,TenPercPAStats)

OnePercDispStats = DispOnePerc[[2]]
FivePercDispStats = DispFivePerc[[2]]
TenPercDispStats = DispTenPerc[[2]]

#write.csv(x=OnePercDispStats, file="OnePercDispStats.csv")
#write.csv(x=FivePercDispStats, file="FivePercDispStats.csv")
#write.csv(x=TenPercDispStats, file="TenPercDispStats.csv")

OnePercPA$Effects = OnePercDispStats$Effects
FivePercPA$Effects = FivePercDispStats$Effects
TenPercPA$Effects = TenPercDispStats$Effects

#st_write(obj=OnePercPA, layer="OnePercPA", dsn="OnePercPA", driver="ESRI Shapefile")
#st_write(obj=FivePercPA, layer="FivePercPA", dsn="FivePercPA", driver="ESRI Shapefile")
#st_write(obj=TenPercPA, layer="TenPercPA", dsn="TenPercPA", driver="ESRI Shapefile")





#####EXCLUDE THOSE WITH NEGATIVE EFFECT AFTER DISPLACEMENT

#Function to remove those that have negative carbon disturbance
ExcLowDen <-function(PASet,PASetStats){
  PASetStats$row = seq(from=1, to=nrow(PASetStats), by=1)
  RemovePA=subset(PASetStats, Effects<0)
  RemovePA$RemPA = as.numeric(RemovePA$row)*-1
  Remove=c(RemovePA$RemPA)
  FinalPAs = PASet[Remove,]
  FinalPAStats = subset(PASetStats, Effects>0)
  newlist <- list(FinalPAs,FinalPAStats)
  return(newlist)}

OnePercFinal <-ExcLowDen(OnePercPA,OnePercFinalDispStats)
FivePercFinal <-ExcLowDen(FivePercPA,FivePercFinalDispStats)
TenPercFinal <-ExcLowDen(TenPercPA,TenPercFinalDispStats)


OnePercFinalPA = OnePercFinal[[1]]
OnePercFinalStats = OnePercFinal[[2]]
plot(OnePercFinalPA)

FivePercFinalPA = FivePercFinal[[1]]
FivePercFinalStats = FivePercFinal[[2]]
plot(FivePercFinalPA)

TenPercFinalPA = TenPercFinal[[1]]
TenPercFinalStats = TenPercFinal[[2]]
plot(TenPercFinalPA)



########REDO FISHERIES DISPLACEMENT WITH FINAL SETS AND CALCULATE FINAL OC DISTURBANCE IMPACT
DispFinalOnePerc = FishDisp(OnePercFinalPA,OnePercFinalStats)
DispFinalFivePerc = FishDisp(FivePercFinalPA,FivePercFinalStats)
DispFinalTenPerc = FishDisp(TenPercFinalPA,TenPercFinalStats)

OnePercFinalDispSVR = DispFinalOnePerc[[1]]
OnePercFinalStats = DispFinalOnePerc[[2]]
OnePercFinalImpact = OnePercFinalDispSVR*StockTot
cellStats(OCDisturb,sum)-cellStats(OnePercFinalImpact,sum)
(cellStats(OCDisturb,sum)-cellStats(OnePercFinalImpact,sum))/cellStats(OCDisturb,sum)*100
#11511435 or 10.56392%

FivePercFinalDispSVR = DispFinalFivePerc[[1]]
FivePercFinalStats = DispFinalFivePerc[[2]]
FivePercFinalImpact = FivePercFinalDispSVR*StockTot
cellStats(OCDisturb,sum)-cellStats(FivePercFinalImpact,sum)
(cellStats(OCDisturb,sum)-cellStats(FivePercFinalImpact,sum))/cellStats(OCDisturb,sum)*100
#20086268 or 18.43294%

TenPercFinalDispSVR = DispFinalTenPerc[[1]]
TenPercFinalStats = DispFinalTenPerc[[2]]
TenPercFinalImpact = TenPercFinalDispSVR*StockTot
cellStats(OCDisturb,sum)-cellStats(TenPercFinalImpact,sum)
(cellStats(OCDisturb,sum)-cellStats(TenPercFinalImpact,sum))/cellStats(OCDisturb,sum)*100
#24357477 or 22.35258%




###### COMPILE NECESSARY DATA INTO FILES AND SAVE
OnePercFinalStats$DensityEffect = OnePercFinalStats$Effects/OnePercFinalStats$Area
FivePercFinalStats$DensityEffect = FivePercFinalStats$Effects/FivePercFinalStats$Area
TenPercFinalStats$DensityEffect = TenPercFinalStats$Effects/TenPercFinalStats$Area

OnePercFinalStats$PropEffect = OnePercFinalStats$Effects/cellStats(OCDisturb,sum)*100
FivePercFinalStats$PropEffect = FivePercFinalStats$Effects/cellStats(OCDisturb,sum)*100
TenPercFinalStats$PropEffect = TenPercFinalStats$Effects/cellStats(OCDisturb,sum)*100

OnePercFinalStats$Ratio = OnePercFinalStats$PropEffect/OnePercFinalStats$PropValue
FivePercFinalStats$Ratio = FivePercFinalStats$PropEffect/FivePercFinalStats$PropValue
TenPercFinalStats$Ratio = TenPercFinalStats$PropEffect/TenPercFinalStats$PropValue

AddDataOne = cbind(OnePercFinalStats[,3:17],OnePercFinalPA)
AddDataFive = cbind(FivePercFinalStats[,3:17],FivePercFinalPA)
AddDataTen = cbind(TenPercFinalStats[,3:17],TenPercFinalPA)

OnePercFinalPA = st_sf(AddDataOne)
FivePercFinalPA = st_sf(AddDataFive)
TenPercFinalPA = st_sf(AddDataTen)


#write.csv(x=OnePercFinalStats, file="OnePercFinalStats.csv")
#write.csv(x=FivePercFinalStats, file="FivePercFinalStats.csv")
#write.csv(x=TenPercFinalStats, file="TenPercFinalStats.csv")

#writeRaster(OnePercFinalDispSVR,"OnePercFinalDispSVR.tif",overwrite=TRUE)
#writeRaster(FivePercFinalDispSVR,"FivePercFinalDispSVR.tif",overwrite=TRUE)
#writeRaster(TenPercFinalDispSVR,"TenPercFinalDispSVR.tif",overwrite=TRUE)

#writeRaster(OnePercFinalImpact,"OnePercFinalImpact.tif",overwrite=TRUE)
#writeRaster(FivePercFinalImpact,"FivePercFinalImpact.tif",overwrite=TRUE)
#writeRaster(TenPercFinalImpact,"TenPercFinalImpact.tif",overwrite=TRUE)

#st_write(obj=OnePercFinalPA, layer="OnePercFinalPA", dsn="OnePercFinalPA", driver="ESRI Shapefile")
#st_write(obj=FivePercFinalPA, layer="FivePercFinalPA", dsn="FivePercFinalPA", driver="ESRI Shapefile")
#st_write(obj=TenPercFinalPA, layer="TenPercFinalPA", dsn="TenPercFinalPA", driver="ESRI Shapefile")


